@@ -1,3 +1,5 @@
+import os
+
 from flask import Flask, url_for
 from flask.ext.login import LoginManager
 from flask.ext.sqlalchemy import SQLAlchemy, _SessionSignalEvents
@@ -9,7 +11,12 @@ from sqlalchemy_continuum import (
 )
 from sqlalchemy_continuum.plugins import FlaskPlugin
 from sqlalchemy_continuum.transaction import TransactionFactory
-from tests import TestCase
+from tests import (
+    TestCase,
+    get_driver_name,
+    get_dns_from_driver,
+    uses_native_versioning
+)
 
 
 class TestFlaskPlugin(TestCase):
@@ -68,32 +75,56 @@ class TestFlaskPlugin(TestCase):
         self.User = User
 
     def setup_views(self):
-        @self.app.route('/')
-        def index():
+        @self.app.route('/simple-flush')
+        def test_simple_flush():
             article = self.Article()
             article.name = u'Some article'
             self.session.add(article)
             self.session.commit()
             return ''
 
+        @self.app.route('/raw-sql-and-flush')
+        def test_raw_sql_and_flush():
+            self.session.execute(
+                "INSERT INTO article (name) VALUES ('some article')"
+            )
+            article = self.Article()
+            article.name = u'Some article'
+            self.session.add(article)
+            self.session.flush()
+            self.session.execute(
+                "INSERT INTO article (name) VALUES ('some article')"
+            )
+            self.session.commit()
+            return ''
+
     def test_versioning_inside_request(self):
         user = self.User(name=u'Rambo')
         self.session.add(user)
         self.session.commit()
         self.login(user)
-        self.client.get(url_for('.index'))
+        self.client.get(url_for('.test_simple_flush'))
 
         article = self.session.query(self.Article).first()
         tx = article.versions[-1].transaction
         assert tx.user.id == user.id
 
+    def test_raw_sql_and_flush(self):
+        user = self.User(name=u'Rambo')
+        self.session.add(user)
+        self.session.commit()
+        self.login(user)
+        self.client.get(url_for('.test_raw_sql_and_flush'))
+        assert (
+            self.session.query(versioning_manager.transaction_cls).count() == 2
+        )
+
 
 class TestFlaskPluginWithoutRequestContext(TestCase):
     plugins = [FlaskPlugin()]
+    user_cls = 'User'
 
     def create_models(self):
-        TestCase.create_models(self)
-
         class User(self.Model):
             __tablename__ = 'user'
             __versioned__ = {
@@ -104,6 +135,8 @@ class TestFlaskPluginWithoutRequestContext(TestCase):
             name = sa.Column(sa.Unicode(255), nullable=False)
         self.User = User
 
+        TestCase.create_models(self)
+
     def test_versioning_outside_request(self):
         user = self.User(name=u'Rambo')
         self.session.add(user)
@@ -178,13 +211,19 @@ class TestFlaskPluginWithFlaskSQLAlchemyExtension(object):
         make_versioned()
 
         versioning_manager.transaction_cls = TransactionFactory()
+        versioning_manager.options['native_versioning'] = (
+            uses_native_versioning()
+        )
 
         self.create_models()
 
         sa.orm.configure_mappers()
 
         self.app = Flask(__name__)
-        self.app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///:memory:'
+        # self.app.config['SQLALCHEMY_ECHO'] = True
+        self.app.config['SQLALCHEMY_DATABASE_URI'] = get_dns_from_driver(
+            get_driver_name(os.environ.get('DB', 'sqlite'))
+        )
         self.db.init_app(self.app)
         self.app.secret_key = 'secret'
         self.app.debug = True
@@ -195,7 +234,10 @@ class TestFlaskPluginWithFlaskSQLAlchemyExtension(object):
 
     def teardown_method(self, method):
         remove_versioning()
+        self.db.session.remove()
         self.db.drop_all()
+        self.db.session.close_all()
+        self.db.engine.dispose()
         self.context.pop()
         self.context = None
         self.client = None
@@ -218,3 +260,14 @@ class TestFlaskPluginWithFlaskSQLAlchemyExtension(object):
         self.db.session.add(article)
         self.db.session.commit()
         assert len(article.versions[0].tags) == 1
+
+    def test_create_transaction_with_scoped_session(self):
+        article = self.Article()
+        article.name = u'Some article'
+        article.content = u'Some content'
+        self.db.session.add(article)
+        uow = versioning_manager.unit_of_work(self.db.session)
+        transaction = uow.create_transaction(self.db.session)
+        assert transaction.id
+
+
